FocusKoidChain

Struct FocusKoidChain 

pub struct FocusKoidChain {
    pub focus_chain: Option<Vec<u64>>,
    /* private fields */
}
A FocusKoidChain serves almost the same purpose as a FocusChain, but is intended for applications that merely need to identify views in the chain and do not need to watch their state.

Fields

focus_chain: Option<Vec<u64>>